# Mhb_Math

mhb-math is a simple python package for useful mathematical functions.

## Equations
This module provides access to the mathematical functions about equations. To use these functions you have to import the module using 
> import equations 

## Functions
This module provides access to the basic mathematical functions. To use these functions you have to import the module using 
> import functions 